import numpy as np
import sys as sys

EPS = 10.**-7

def FILEREADER_FOR_NUMCOL( filename, 
                           TOP_IS_LABELS = 1, 
                           LSIDE_IS_INTLABELS = 1):

    fff = open(filename,'rU')
    X = fff.readlines()
    fff.close()
    # split by whitespace as default; if you have more than 
    # one line in a file, loop through

    Nline_in = len(X)

    intl = []
    V = []
    labs = []
    if TOP_IS_LABELS:
        labs = X[0].split()

    for i in range(TOP_IS_LABELS, Nline_in):
        xx = X[i]
        yy = xx.split()
        zz = []
        if yy: # get rid of empty lines
            for j in range(0, LSIDE_IS_INTLABELS):
                intl.append( int(yy[j]) )
            for j in range(LSIDE_IS_INTLABELS, len(yy)):
                zz.append( float(yy[j]) )
            V.append(zz)

    if len(np.shape(V))<2:
        print("** ERROR when reading in array: ")
        print("   not equal length of columns?")
        sys.exit(1)

    V = np.array(V, dtype=float)
    if LSIDE_IS_INTLABELS:
        intl = np.array(intl, dtype=int)

    if not(labs):
        for i in range(np.shape(V)[1]):
            labs.extend(str(i))

    # return: the array of data numbers; the top row labels; the LHS
    # ints.
    return V, labs, intl

def make_ofile_name( fff ):
    # also replace colon in file name. Ick.
    ggg = fff.replace('.txt', '_VAL.dat')
    hhh = ggg.replace(':', '__')

    return hhh
    
def calc_othr( V ):

    Nr, Nc = np.shape( V )

    omat = np.zeros((Nr, 4), dtype = float)

    for i in range(Nr):
        x = V[i]
        
        # make sure ME is in 2.5-97% interval
        if (x[0]-x[2])*(x[0]-x[6]) > 0:
            print("** ERROR: [%d]th ME not in %ile interval " % i)
            print("   ME=%f, int: [%f, %f]" % ( x[0], x[2], x[6]))
            sys.exit(2)

        # using different special cases here, prob not sooo necessary,
        # but leaving in for now; checking for 0s is a ~pain, possibly.
        if abs(x[0]) < EPS:
            denom = 1.0 # doesn't matter, effect is 0 and output thr
                      # will be 0
        elif abs(x[2]) < EPS or abs(x[6]) < EPS:
            denom = abs(x[0])
            #print(" !  ME=%f, int: [%f, %f] %f  %f" % 
            #      ( x[0], x[2], x[6], denom, abs(x[0]) / denom))

        ### check if percentile interval contains 0 or not
        elif x[2]*x[6] > 0.0: # nope, does not
            # denom is diff between ME and the %ile that is between it
            # and zero
            if abs(x[0]) > abs(x[2]) :
                denom = abs(x[0] - x[2] )
            else:
                denom = abs(x[0] - x[6] )
        else:              # yep, it does
            # get end point on opposite side from ME for denom calc
            if x[0]*x[2] < 0.0 :
                denom = abs(x[0] - x[2] )
            else:
                denom = abs(x[0] - x[6] )

        if denom <= 0 :
            print("**ERROR: [%d]th row; denom can't be <=0!" % i)
            print("   ME=%f, int: [%f, %f]" % (x[0], x[2], x[6]))
            sys.exit(2)

        omat[i,0] = x[0]                   # ME
        omat[i,1] = abs(x[0]) / denom      # threshold thing
        omat[i,2] = x[2]                   # 2.5%
        omat[i,3] = x[6]                   # 97.5.5%
        
    return omat

def write_out_cols( ofile, omat, intlabs ):

    Nr, Nc = np.shape(omat)
    Nint = len(intlabs)

    if Nint - Nr:
        print("**ERROR: numbers of columns don't match!")
        print("  %d != %d " % ( Nr, Nint) )
        sys.exit(5)

    # also write out the interval, for no particular reason except
    # visual check
    f = open(ofile, 'w')
    for i in range(Nr):
        f.write("%10d %10.6f %10.6f %10.6f %10.6f\n" % 
                ( intlabs[i], 
                  omat[i,0],
                  omat[i,1],
                  omat[i,2],
                  omat[i,3] ) )
    f.close()

def make_3dcalc_equals_expr( omat, ilab ):

    Nr, Nc = np.shape(omat)

    ostrME  = 'equals(a,0)*0'
    ostrTHR = 'equals(a,0)*0'

    for i in range(Nr):
        ll  = ilab[i]
        ME  = omat[i, 0]
        thr = omat[i, 1]

        ostrME+= '+equals(a,'+str(ll)+')*('+str(ME)+')'
        ostrTHR+= '+equals(a,'+str(ll)+')*('+str(thr)+')'

    return ostrME, ostrTHR

def write_out_3dcalc_expr( ofile, ostr, olab ):

    ofilestr = ofile.replace("VAL.dat", olab+".dat" )

    # also write out the interval, for no particular reason except
    # visual check
    f = open(ofilestr, 'w')
    f.write("%s\n" % 
            ( ostr ) )
    f.close()
    return ofilestr

# =====================================================================

if __name__ == "__main__":

    argv = sys.argv
    if len(argv) != 2 :
        print("ERROR: one and only one argument entered, a *.txt file name")
        sys.exit(3)

    ifile = argv[1]

    vals, labs, intlabs = FILEREADER_FOR_NUMCOL( ifile )
    ofile               = make_ofile_name( ifile )
    omat                = calc_othr( vals )
    
    write_out_cols( ofile, omat, intlabs )

    ostrME, ostrTHR = make_3dcalc_equals_expr( omat, intlabs )
    ofileME = write_out_3dcalc_expr( ofile, ostrME, "ME" )
    ofileTHR = write_out_3dcalc_expr( ofile, ostrTHR, "THR" )

    print("++ Done! See:\t%s" % ofile)
    print("++ Done! See:\t%s" % ofileME)
    print("++ Done! See:\t%s" % ofileTHR)
