#!/bin/tcsh

set refset = HaskinsPeds_NL_template1.0+tlrc.HEAD #mni_ulay.nii.gz #MNI152_2009_template.nii.gz
set prefin = "SIDE2"
set ivol   = shen_2mm_268_parcellation_HaskinsPeds+tlrc.HEAD #${prefin}_clust_tall_map.nii.gz
set ivolee = shen_2mm_268_parcellation_HaskinsPeds+tlrc.HEAD #${prefin}_clust_tall_EE.nii.gz

set portnum = `afni -available_npb_quiet`
setenv AFNI_ENVIRON_WARNINGS NO
setenv SUMA_DriveSumaMaxCloseWait 6
setenv SUMA_DriveSumaMaxWait 6
setenv AFNI_SUMA_LINECOLOR_FORCE_DEF black #limegreen #black
setenv AFNI_IMAGE_LABEL_MODE 1
setenv AFNI_IMAGE_LABEL_SIZE 4
setenv AFNI_IMAGE_LABEL_COLOR white
setenv AFNI_IMAGE_LABEL_SETBACK 0.01
setenv AFNI_DEFAULT_IMSAVE       png

# ----------- set some pars ------------------------

set odir    = "."                # output dir: here
set impref  = "img_SIDE2"        # prefix of file

set OW = "OPEN_WINDOW"
set opac = 9 # opacity
# montage dims
set mx = 4
set my = 1
set ftype = PNG
set bufac   = "1"                # blowup factor
set frange  = 0.4                # olay range
set my_cbar = "Reds_and_Blues_Inv"  # cbar
set gapord = ( 10 7 6 )           # delta slices
set coor_type = "SET_DICOM_XYZ"
set coors = ( -5.0 0.0 0.0 )      # jump here

if ( 0 ) then #!!!!!!!!!!!!!!!!!!!!!!!!!!!
# ----------- make surfaces
IsoSurface                \
    -overwrite            \
    -isorois+dsets        \
    -input $ivol          \
    -o_gii cc_${prefin}   \
    -Tsmooth 0 0 -remesh 1
endif # !!!!!!!!!!!!!!!!!!!

# ------------- open + drive viewers ---------------------

afni -npb $portnum -niml -yesplugouts &
plugout_drive -echo_edu                                  \
    -npb $portnum                                        \
    -com "SWITCH_UNDERLAY ${refset}"                     \
    -com "SWITCH_OVERLAY  ${ivolee}"                      \
     -com "SET_XHAIRS  OFF"                                   \
    -com "SET_FUNC_VISIBLE +"                          \
    -com "SET_FUNC_RANGE  $frange"                   \
    -com "SET_THRESHNEW 0.0"                           \
    -com "SET_PBAR_ALL -99 1.0 $my_cbar" \
     -com "$coor_type $coors"                                          \
     -com "$OW sagittalimage ifrac=1 opacity=${opac} mont=${mx}x${my}:${gapord[1]}" \
     -com "$OW coronalimage  ifrac=1 opacity=${opac} mont=${mx}x${my}:${gapord[2]}" \
     -com "$OW axialimage    ifrac=1 opacity=${opac} mont=${mx}x${my}:${gapord[3]}" &


  #   -com "SAVE_${ftype} sagittalimage ${odir}/${impref}.sag blowup=${bufac}" \
  #   -com "SAVE_${ftype} coronalimage  ${odir}/${impref}.cor blowup=${bufac}" \
  #   -com "SAVE_${ftype} axialimage    ${odir}/${impref}.axi blowup=${bufac}" \

suma -echo_edu \
    -npb $portnum           \
    -onestate -niml         \
    -i node_outlines_nosmoothing/shen268_Hask.k*.gii    \
    -vol $refset            \
    -sv $refset &

echo "\n\nNAP 1/4...\n\n"
sleep 3

DriveSuma                                              \
    -npb $portnum                                      \
    -com viewer_cont -key "t" -key "." 

plugout_drive -echo_edu                                  \
    -npb $portnum                                        \
    -com "SWITCH_UNDERLAY ${refset}"                     \
    -com "SWITCH_OVERLAY  ${ivolee}"                      \
     -com "SET_XHAIRS  OFF"                                   \
    -com "SET_FUNC_VISIBLE +"                          \
    -com "SET_FUNC_RANGE  $frange"                   \
    -com "SET_THRESHNEW 0.0"                           \
    -com "SET_PBAR_ALL -99 1.0 $my_cbar" \
     -com "$coor_type $coors"                                          \
     -com "$OW sagittalimage opacity=${opac} mont=${mx}x${my}:${gapord[1]}" \
     -com "$OW coronalimage  opacity=${opac} mont=${mx}x${my}:${gapord[2]}" \
     -com "$OW axialimage    opacity=${opac} mont=${mx}x${my}:${gapord[3]}" \
    -quit ./ &
